@@ -1,6 +1,6 @@
 #pragma once
-#include "glm/glm.hpp"
-#include "cppcodec/base64_rfc4648.hpp"
+#include "deps/glm/glm.hpp"
+#include "deps/cppcodec/base64_rfc4648.hpp"
 #include <vector>
 #include <iostream>
 #include <memory>
